aboutsummaryrefslogtreecommitdiff
path: root/video/smk_decoder.h
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/smk_decoder.h
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/smk_decoder.h')
-rw-r--r--video/smk_decoder.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/video/smk_decoder.h b/video/smk_decoder.h
index cb73810df9..3476dbe534 100644
--- a/video/smk_decoder.h
+++ b/video/smk_decoder.h
@@ -33,7 +33,7 @@ namespace Audio {
class QueuingAudioStream;
}
-namespace Graphics {
+namespace Video {
class BigHuffmanTree;
@@ -66,8 +66,8 @@ public:
uint16 getHeight() const { return _surface->h; }
uint32 getFrameCount() const { return _frameCount; }
uint32 getElapsedTime() const;
- const Surface *decodeNextFrame();
- PixelFormat getPixelFormat() const { return PixelFormat::createFormatCLUT8(); }
+ const Graphics::Surface *decodeNextFrame();
+ Graphics::PixelFormat getPixelFormat() const { return Graphics::PixelFormat::createFormatCLUT8(); }
const byte *getPalette() { _dirtyPalette = false; return _palette; }
bool hasDirtyPalette() const { return _dirtyPalette; }
virtual void handleAudioTrack(byte track, uint32 chunkSize, uint32 unpackedSize);
@@ -124,7 +124,7 @@ protected:
Common::Rational _frameRate;
uint32 _frameCount;
- Surface *_surface;
+ Graphics::Surface *_surface;
Audio::Mixer::SoundType _soundType;
Audio::Mixer *_mixer;
@@ -138,6 +138,6 @@ protected:
BigHuffmanTree *_TypeTree;
};
-} // End of namespace Graphics
+} // End of namespace Video
#endif